@@ -42,24 +42,11 @@ globus_gram_job_manager_state_file_set(
 {
     int                                 rc = GLOBUS_SUCCESS;
 
-    if(request->config->job_state_file_dir == GLOBUS_NULL)
-    {
-        *state_file = globus_common_create_string(
-                "%s/tmp/gram_job_state/%s.%s.%s",
-                request->config->globus_location ?
-                request->config->globus_location : "",
-                request->config->logname,
-                request->config->hostname,
-                request->uniq_id);
-    }
-    else
-    {
-        *state_file = globus_common_create_string(
-                "%s/job.%s.%s",
-                request->config->job_state_file_dir,
-                request->config->hostname,
-                request->uniq_id);
-    }
+    *state_file = globus_common_create_string(
+            "%s/job.%s.%s",
+            request->config->job_state_file_dir,
+            request->config->hostname,
+            request->uniq_id);
 
     if (*state_file == NULL)
     {
@@ -68,6 +55,36 @@ globus_gram_job_manager_state_file_set(
         goto create_state_file_failed;
     }
 
+    if ((access(*state_file, R_OK) != 0) && errno == ENOENT)
+    {
+        char * dirname_end;
+
+        /* If it doesn't exist yet, we'll use a per-user state file dir
+         * to reduce the size of the global state file dir (GT-157)
+         */
+        free(*state_file);
+
+        *state_file = globus_common_create_string(
+                "%s/%s/%s/%s/job.%s",
+                request->config->job_state_file_dir,
+                request->config->logname,
+                request->config->service_tag,
+                request->config->jobmanager_type,
+                request->uniq_id);
+
+        if (*state_file == NULL)
+        {
+            rc = GLOBUS_GRAM_PROTOCOL_ERROR_MALLOC_FAILED;
+
+            goto create_state_file_failed;
+        }
+        dirname_end = strrchr(*state_file, '/');
+        *dirname_end = '\0';
+
+        globus_i_gram_mkdir(*state_file);
+        *dirname_end = '/';
+    }
+
 create_state_file_failed:
     return rc;
 }
@@ -387,7 +404,7 @@ globus_gram_job_manager_state_file_read(
     char *                              buffer = NULL;
     size_t                              file_len;
     struct stat                         statbuf;
-    int                                 rc;
+    int                                 rc = GLOBUS_SUCCESS;
     int                                 i;
     unsigned long                       tmp_timestamp;
 
@@ -562,6 +579,7 @@ globus_gram_job_manager_state_file_read(
         strcmp(buffer, request->config->jobmanager_type) != 0)
     {
         /* Job should be handled by another job manager */
+        rc = GLOBUS_GRAM_PROTOCOL_ERROR_OLD_JM_ALIVE;
         goto free_cache_tag;
     }
     if (fgets( buffer, file_len, fp ) == NULL)
@@ -628,12 +646,12 @@ globus_gram_job_manager_state_file_read(
     rc = globus_gram_job_manager_read_callback_contacts(request, fp);
     if(rc != GLOBUS_SUCCESS)
     {
-        goto free_scratchdir;
+        goto free_staging;
     }
 
     if (fgets( buffer, file_len, fp ) == NULL)
     {
-        goto free_scratchdir;
+        goto free_callback_contacts;
     }
     buffer[strlen(buffer)-1] = '\0';
     if(strcmp(buffer, " ") != 0)
@@ -723,22 +741,24 @@ globus_gram_job_manager_state_file_read(
     }
     if (fgets( buffer, file_len, fp ) == NULL)
     {
-        goto free_client_address;
+        goto free_user_dn;
     }
     request->expected_terminal_state = atoi( buffer );
 
     if (fgets( buffer, file_len, fp ) == NULL)
     {
-        goto free_client_address;
+        goto free_user_dn;
     }
     buffer[strlen(buffer)-1] = '\0';
     if (request->config && strcmp(buffer, request->config->service_tag) != 0)
     {
-        goto free_client_address;
+        /* Job should be handled by another job manager */
+        rc = GLOBUS_GRAM_PROTOCOL_ERROR_OLD_JM_ALIVE;
+        goto free_user_dn;
     }
     if(fgets( buffer, file_len, fp ) == NULL)
     {
-        goto free_client_address;
+        goto free_user_dn;
     }
     buffer[strlen(buffer)-1] = '\0';
     if(strcmp(buffer, " ") != 0)
@@ -779,6 +799,12 @@ free_original_job_id_string:
         free(request->original_job_id_string);
         request->original_job_id_string = NULL;
     }
+free_user_dn:
+    if (request->job_stats.user_dn)
+    {
+        free(request->job_stats.user_dn);
+    }
+
 free_client_address:
     if (request->job_stats.client_address != NULL)
     {
@@ -791,6 +817,13 @@ free_gateway_user:
         free(request->gateway_user);
         request->gateway_user = NULL;
     }
+
+free_callback_contacts:
+    globus_gram_job_manager_contact_list_free(request);
+
+free_staging:
+    globus_gram_job_manager_staging_free_all(request);
+
 free_scratchdir:
     if (request->scratchdir != NULL)
     {
@@ -816,7 +849,10 @@ free_job_id_string:
         request->job_id_string = NULL;
     }
 error_exit:
-    rc = GLOBUS_GRAM_PROTOCOL_ERROR_READING_STATE_FILE;
+    if (rc == GLOBUS_SUCCESS)
+    {
+        rc = GLOBUS_GRAM_PROTOCOL_ERROR_READING_STATE_FILE;
+    }
 
     globus_gram_job_manager_request_log(
             request,
@@ -840,7 +876,7 @@ fopen_state_file_failed:
         free(buffer);
     }
 exit:
-    return GLOBUS_GRAM_PROTOCOL_ERROR_READING_STATE_FILE;
+    return rc;
 }
 /* globus_gram_job_manager_state_file_read() */
 
